==> MRAConnector-0.84.tar.bz2: MRAConnector-0.84/core/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Protocol.Client/PopCommand.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2012 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Pop3.Protocol.Client {
  // handles '6. Client Commands'
  public sealed class PopCommand {
    public string Command {
      get; private set;
    }

    public string[] Parameters {
      get; private set;
    }

    public PopCommand(string command)
      : this(command, new string[0])
    {
    }

    public PopCommand(string command, params string[] parameters)
    {
      this.Command = command;
      this.Parameters = parameters ?? new string[0];
    }

    public override string ToString()
    {
      return string.Format("{{Command={0}, Parameters={1}}}", Command, string.Join(", ", Parameters));
    }
  }
}

==> MRAConnector-1.12.tar.bz2: MRAConnector-1.12/core/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Protocol.Client/PopCommand.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2014 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Pop3.Protocol.Client {
  // handles '6. Client Commands'
  public sealed class PopCommand {
    public string Command {
      get; private set;
    }

    public string[] Parameters {
      get; private set;
    }

    public PopCommand(string command)
      : this(command, EmptyArray<string>.Instance)
    {
    }

    public PopCommand(string command, params string[] parameters)
    {
      this.Command = command;
      this.Parameters = parameters ?? EmptyArray<string>.Instance;
    }

    public override string ToString()
    {
      return string.Format("{{Command={0}, Parameters={1}}}", Command, string.Join(", ", Parameters));
    }
  }
}
